@@ -1,9 +1,8 @@
 package JSON::PP::Boolean;
 
 use strict;
-use warnings;
-use overload ();
-overload::unimport('overload', qw(0+ ++ -- fallback));
+require overload;
+local $^W;
 overload::import('overload',
     "0+"     => sub { ${$_[0]} },
     "++"     => sub { $_[0] = ${$_[0]} + 1 },
@@ -11,7 +10,7 @@ overload::import('overload',
     fallback => 1,
 );
 
-our $VERSION = '4.17_01';
+$JSON::PP::Boolean::VERSION = '4.01';
 
 1;
 
